Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.PersonVersandart Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.PersonVersandart einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.PersonVersandart) | Gemeinde_Modelle.PersonVersandart |
__str__(self) (Definiert in Gemeinde_Modelle.PersonVersandart) | Gemeinde_Modelle.PersonVersandart |
keyFeldNavi (Definiert in Gemeinde_Modelle.PersonVersandart) | Gemeinde_Modelle.PersonVersandart | static
R_person (Definiert in Gemeinde_Modelle.PersonVersandart) | Gemeinde_Modelle.PersonVersandart | static
R_versandart (Definiert in Gemeinde_Modelle.PersonVersandart) | Gemeinde_Modelle.PersonVersandart | static